use Data_DPE.dta

*********** Table 1
gen outatt=totter1
replace outatt=0 if samebase==1
collapse (max) y_start y_end endstr mul_base dur ///
	empire pch tch rcsr sq left nat right rel (firstnm) ideology ///
	(sum) tter1 dter1 totter1 outatt, by(gid)
table ideology, c(freq mean dur sum mul_bases sum totter1 sum outatt)

use Data_DPE.dta, clear
keep if year<1991
gen outatt=totter1
replace outatt=0 if samebase==1
collapse (max) y_start y_end endstr mul_base dur1 ///
	empire pch tch rcsr sq left nat right rel (firstnm) ideology ///
	(sum) tter1 dter1 totter1 outatt, by(gid)
table ideology, c(freq mean dur1 sum mul_bases sum totter1 sum outatt)

use Data_DPE.dta, clear
keep if year>=1991
gen outatt=totter1
replace outatt=0 if samebase==1
collapse (max) y_start y_end endstr mul_base dur ///
	empire pch tch rcsr sq left nat right rel (firstnm) ideology ///
	(sum) tter1 dter1 totter1 outatt, by(gid)
table ideology, c(freq mean dur sum mul_bases sum totter1 sum outatt)


*********** Figure 1 & Table 2
use Data_DPE.dta, clear
preserve // preserve original dataset
// Data for Figure 1
gen outrans=tter1
replace outrans=0 if samebase==1
table year, c(sum tter1 sum outrans)
// Table 2
collapse (max) empire pch tch rcsr sq (firstnm) ideology, by(gid)
table ideology, c(sum empire sum rcsr sum pch sum sq sum tch)
restore // restore back to original dataset


****** 
gen linc=log(gdppercapita)
gen lpop=log(pop)
gen polit2 = polity^2

*********** Table 3
logit samebase mul_bases left right nat, rob
outreg2 using table3.xls, dec(3) label replace ctitle(Model 1) ///
	title(Logit Regessions)
logit samebase mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using table3.xls, dec(3) label append ctitle(Model 2) drop(i.year)
logit samebase mul_bases rcsr pch sq tch, rob  // empire is the base category
outreg2 using table3.xls, dec(3) label append ctitle(Model 3) drop(i.year)
logit samebase mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using table3.xls, dec(3) label append ctitle(Model 4) drop(i.year)
logit samebase mul_bases left right nat rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using table3.xls, dec(3) label append ctitle(Model 5) drop(i.year) ///
sortvar(mul_bases left nat right rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA)


*********** Figure 2: Average Marginal Effects with 95% CIs	
label define left 0 "no" 1 "Left wing"
label values left left
label define nat 0 "no" 1 "Nationalist"
label values nat nat
label define right 0 "no" 1 "Right wing"
label values right right

logit samebase i.mul_bases i.left i.right i.nat linc lpop polity tradeopenness2010usd ///
	i.EAP i.ECA i.LAC i.NA i.SAS i.SSA i.year, rob
margins, dydx(left nat right)	// Average Marginal Effects
marginsplot, xtitle(Terrorist Group Ideology) ytitle(Marginal Effect) ///  // AME with 95% CIs
	ylabel(,nogrid)
testparm 1.left 1.nat, equal
testparm 1.left 1.right, equal
testparm 1.right 1.nat, equal

logit samebase i.mul_bases i.rcsr i.pch i.sq i.tch linc lpop polity tradeopenness2010usd ///
	i.EAP i.ECA i.LAC i.NA i.SAS i.SSA i.year, rob
margins, dydx(rcsr pch sq tch)
marginsplot, xtitle(Terrorist Group Goal) ytitle(Marginal Effect) ///  // AME with 95% CIs
	ylabel(,nogrid)
testparm 1.rcsr 1.pch, equal
testparm 1.rcsr 1.sq, equal
testparm 1.rcsr 1.tch, equal
testparm 1.pch 1.sq, equal
testparm 1.pch 1.tch, equal
testparm 1.sq 1.tch, equal


********** Table 4: Divide into time sub-periods
logit samebase mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if year<1991, rob
outreg2 using table4.xls, dec(3) label replace ctitle(Before 1991) drop(i.year) ///
	title(Logit Regessions: dividing data into sub-periods)	
logit samebase mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if year<1991, rob
outreg2 using table4.xls, dec(3) label append ctitle(Before 1991) drop(i.year)
logit samebase mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if year>=1991, rob
outreg2 using table4.xls, dec(3) label append ctitle(1991-2016) drop(i.year)	
logit samebase mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if year>=1991, rob
outreg2 using table4.xls, dec(3) label append ctitle(1991-2016) drop(i.year)	
logit samebase mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if year>=2002, rob
outreg2 using table4.xls, dec(3) label append ctitle(2002-2016) drop(i.year)	
logit samebase mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if year>=2002, rob
outreg2 using table4.xls, dec(3) label append ctitle(2002-2016) drop(i.year) ///
sortvar(mul_bases left nat right rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA)


****** Appendix Table A1 Descriptive Stats
outreg2 using TableA1.xls, sum(log) keep(samebase mul_bases left right nat rel ///
	empire rcsr pch sq tch linc lpop polity tradeopenness2010usd EAP ECA LAC ///
	MENA NA SAS SSA state_sponsor_ever) sortvar(samebase mul_bases left nat ///
	right rel empire rcsr pch sq tch state_sponsor_ever linc lpop polity polit2 ///
	tradeopenness2010usd EAP ECA LAC MENA NA SAS SSA) replace

	
********** Appendix Table A2: re-estimate Table 3, holding sample size constant
qui logit samebase mul_bases left right nat rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
gen samp=1 if e(sample)

logit samebase mul_bases left right nat if samp==1, rob
outreg2 using tableA2.xls, dec(3) label replace ctitle(Model 1) ///
	title(Logit Regessions)
logit samebase mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if samp==1, rob
outreg2 using tableA2.xls, dec(3) label append ctitle(Model 2) drop(i.year)
logit samebase mul_bases rcsr pch sq tch if samp==1, rob  // empire is the base category
outreg2 using tableA2.xls, dec(3) label append ctitle(Model 3) drop(i.year)
logit samebase mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year if samp==1, rob
outreg2 using tableA2.xls, dec(3) label append ctitle(Model 4) drop(i.year)
logit samebase mul_bases left right nat rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using tableA2.xls, dec(3) label append ctitle(Model 5) drop(i.year) ///
sortvar(mul_bases left nat right rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA)

	
********** Appendix Table A3:
// Add state sponsorship: data for only 90 groups
logit samebase mul_bases left nat state_sponsor_ever linc lpop polity ///
	EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using tableA3.xls, dec(3) label replace ctitle(Model 1) drop(i.year)
// add peaksize
logit samebase mul_bases left right nat lnpeaksize linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using tableA3.xls, dec(3) label append ctitle(Model 2) drop(i.year)
logit samebase mul_bases rcsr pch sq tch lnpeaksize linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using tableA3.xls, dec(3) label append ctitle(Model 3) drop(i.year)
// add polity squared
logit samebase mul_bases left right nat linc lpop polity polit2 ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using tableA3.xls, dec(3) label append ctitle(Model 4) drop(i.year)
logit samebase mul_bases rcsr pch sq tch linc lpop polity polit2 ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using tableA3.xls, dec(3) label append ctitle(Model 5) drop(i.year) ///
sortvar(mul_bases left nat right rcsr pch sq tch state_sponsor_ever lnpeaksize linc ///
	lpop polity polit2 tradeopenness2010usd EAP ECA LAC NA SAS SSA)
	
	
// Tables 5 & 6
clear all
use Data_DPE.dta
bysort gid year: egen totatt=total(totter1), miss
gen temp=totter1
replace temp=0 if samebase==1
bysort gid year: egen outatt=total(temp), miss
duplicates drop gid year, force
gen ratatt=outatt/totatt
gen linc=log(gdppercapita)
gen lpop=log(pop)


*********** Table 5: share of attacks outside home base(s)
fracreg logit ratatt mul_bases left right nat, vce(rob)
outreg2 using table5.xls, dec(3) label replace ctitle(Model 1) ///
	title(Fractional Logit Regessions)
fracreg logit ratatt mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year, vce(rob)
outreg2 using table5.xls, dec(3) label append ctitle(Model 2) drop(i.year)
fracreg logit ratatt mul_bases rcsr pch sq tch, vce(rob)  // empire is the base category
outreg2 using table5.xls, dec(3) label append ctitle(Model 3) drop(i.year)
fracreg logit ratatt mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year, vce(rob)
outreg2 using table5.xls, dec(3) label append ctitle(Model 4) drop(i.year)
fracreg logit ratatt mul_bases left right nat rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, vce(rob)
outreg2 using table5.xls, dec(3) label append ctitle(Model 5) drop(i.year) ///
sortvar(mul_bases left nat right rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA)

	
*********** Table 6: count of attacks outside home base(s)
nbreg outatt mul_bases left right nat, rob
outreg2 using table6.xls, dec(3) label replace ctitle(Model 1) ///
	title(Negative Binomial Regessions)
nbreg outatt mul_bases left right nat linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using table6.xls, dec(3) label append ctitle(Model 2) drop(i.year)
nbreg outatt mul_bases rcsr pch sq tch, rob  // empire is the base category
outreg2 using table6.xls, dec(3) label append ctitle(Model 3) drop(i.year)
nbreg outatt mul_bases rcsr pch sq tch linc lpop polity tradeopenness2010usd ///
	EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using table6.xls, dec(3) label append ctitle(Model 4) drop(i.year)
nbreg outatt mul_bases left right nat rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA i.year, rob
outreg2 using table6.xls, dec(3) label append ctitle(Model 5) drop(i.year) ///
sortvar(mul_bases left nat right rcsr pch sq tch linc lpop polity ///
	tradeopenness2010usd EAP ECA LAC NA SAS SSA)
